pub trait PluginControl {
// Provided methods
fn report(&self) -> PluginReport { ... }
fn plugins_status(&self, _names: &keyexpr) -> Vec<PluginStatusRec<'_>> { ... }
}Expand description
This trait allows getting information about the plugin status and the status of its subplugins, if any.
Provided Methods
Sourcefn report(&self) -> PluginReport
fn report(&self) -> PluginReport
Returns the current state of the running plugin. By default, the state is PluginReportLevel::Normal and the list of messages is empty.
This can be overridden by the plugin implementation if the plugin is able to report its status: no connection to the database, etc.
Sourcefn plugins_status(&self, _names: &keyexpr) -> Vec<PluginStatusRec<'_>>
fn plugins_status(&self, _names: &keyexpr) -> Vec<PluginStatusRec<'_>>
Collects information of sub-plugins matching the _names key expression. The information is richer than the one returned by report(): it contains external information about the running plugin, such as its name, path on disk, load status, etc.
Returns an empty list by default.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".